@@ -27,8 +27,23 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
             self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(video.media.duration.seconds)))))
         except:
             self.durationLabel.setText("--")
-        self.authorLabel.setText("By %s on %s" % (unicode(video.media.credit.text, "utf-8"), video.media.uploaded.text.split("T")[0]))
+
+        try:
+            viewscount = "Viewed: %s" % video.statistics.view_count
+        except:
+            viewscount = ""
+
+        try:
+            raTe = video.rating.average[:1]
+        except:
+            raTe = 0
             
+        stars = "*" * int(raTe)
+            
+        self.authorLabel.setText("By %s on %s" % (unicode(video.media.credit.text, "utf-8"), video.media.uploaded.text.split("T")[0]))
+        self.viewscount.setText("%s" % viewscount)
+        self.ratingstars.setText("%s" % stars)
+        
     def ignoreClick(self, event):
         """
         Propagates the mouse event to the parent.
@@ -41,7 +56,8 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
         """       
         self.thumbLabel.move(0, 2)
         self.durationLabel.move(73, 68)
-        self.widget.setGeometry(QRect(130, 0, 670, 94))
+        self.ratingstars.move(2, 68)
+        self.widget.setGeometry(QRect(115, 0, 670, 94))
         self.checkBox.setVisible(False)
         self.checkBox.setCheckState(Qt.Unchecked)
 
@@ -51,7 +67,8 @@ class VideoItemWidget(QWidget, Ui_VideoItemWidget):
         """
         self.thumbLabel.move(70, 2)
         self.durationLabel.move(143, 68)
-        self.widget.setGeometry(QRect(200, 0, 590, 94))
+        self.ratingstars.move(72, 68)
+        self.widget.setGeometry(QRect(185, 0, 590, 94))
         self.checkBox.setVisible(True)
 
 
@@ -88,10 +105,10 @@ class VideoDownloadItemWidget(QWidget, Ui_VideoDownloadWidget):
         """
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
-            self.widget.setGeometry(QRect(130, 2, 180, 90))
+            self.widget.setGeometry(QRect(115, 2, 180, 90))
             self.progressBar.setGeometry(QRect(330, 2, 120, 90))
         else:
-            self.widget.setGeometry(QRect(130, 2, 470, 90))
+            self.widget.setGeometry(QRect(115, 2, 470, 90))
             self.progressBar.setGeometry(QRect(620, 2, 150, 90))
 
 class CommentWidget(QWidget):
