@@ -33,7 +33,7 @@ class VideoDownloadSettings():
     """
     Provides the video download settings.
     """
-    downloadFolder = "/home/user/MyDocs/.videos"
+    downloadFolder = "/home/user/MyDocs"
     downloadFormat = 18
     formatList = [17, 18, 34, 35, 22]
     defaultTaskStatus = "paused"
