@@ -1,3 +1,4 @@
+#!/usr/bin/env python2.5
 # -*- coding: utf-8 -*-
 
 """
@@ -136,7 +137,7 @@ class NewPlaylistDialog(QDialog, Ui_NewPlaylistDialog):
             self.saveButton.setGeometry(QRect(640, 290, 150, 70))
             self.privateCheckBox.setGeometry(QRect(10, 290, 460, 70))
     
-    def toggleBusy(self, isBusy):
+    def toggleBusy(self, isBusy=False):
         """
         Shows the progress indicator if argument is True, 
         and hides it otherwise.
@@ -154,20 +155,25 @@ class NewPlaylistDialog(QDialog, Ui_NewPlaylistDialog):
         private = self.privateCheckBox.isChecked()
         try:
             self.toggleBusy(True)
-            playlist = youtubeservice.YouTubeDataService.newPlaylist(playlistTitle, playlistDescription, private)
-            playlistId = playlist.playlist_id.text
-            if self.videos == None:
-                QMaemo5InformationBox.information(self, "Your new playlist: \'%s\' has been created" % playlistTitle)
+            result = youtubeservice.YouTubeDataService.newPlaylist(playlistTitle, playlistDescription, private)
+            if (self.videos == None and result):
+                QMaemo5InformationBox.information(self, "Your new playlist: \'%s\' [%s] has been created" % playlistTitle, playlistId)
             else:
-                for video in self.videos:
-                    youtubeservice.YouTubeDataService.addVideoToPlaylist(playlistId, video.media.video_id.text)
-                if len(self.videos) == 1:
-                    QMaemo5InformationBox.information(self, "\'%s\' has been added to your playlist: \'%s\'" % (self.videos[0].media.title.text, playlistTitle))
-                else:
-                    QMaemo5InformationBox.information(self, "Your chosen videos have been added to your playlist: \'%s\'" % playlistTitle)
+                try:
+                    result = youtubeservice.YouTubeDataService.ytService.GetYouTubePlaylistFeed(uri="http://gdata.youtube.com/feeds/api/users/default/playlists?max-results=50&v=2")
+                    playlistId = result.entry[-1].playlist_id.text
+                    for video in self.videos:
+                        youtubeservice.YouTubeDataService.addVideoToPlaylist(playlistId, video.media.video_id.text)
+                    if len(self.videos) == 1:
+                        QMaemo5InformationBox.information(self, "\'%s\' has been added to your playlist: \'%s\'" % (self.videos[0].media.title.text, playlistTitle))
+                    else:
+                        QMaemo5InformationBox.information(self, "Your chosen videos have been added to your playlist: \'%s\'" % playlistTitle)
+                except:
+                    QMaemo5InformationBox.information(self, "Unable to add new video to \'%s\'" % playlistTitle)
+                    
         except:
-            QMaemo5InformationBox.information(self, playlist) 
-        self.toggleBusy(False)
+            QMaemo5InformationBox.information(self, "Unable to add new playlist") 
+        self.toggleBusy()
         self.accept()   
 
 class EditPlaylistDialog(NewPlaylistDialog):
@@ -244,9 +250,12 @@ class EditVideoDialog(NewPlaylistDialog):
         """
         newVideoTitle = unicode(self.titleEdit.text())
         newVideoDescription = unicode(self.descriptionEdit.toPlainText())
+        for link in self.video.link:
+            if link.rel == "self":
+                video_uri = link.href
         try:
             self.toggleBusy(True)
-            youtubeservice.YouTubeDataService.updateVideo(self.video.id.text, newVideoTitle, newVideoDescription)
+            youtubeservice.YouTubeDataService.updateVideo(video_uri, newVideoTitle, newVideoDescription)
             QMaemo5InformationBox.information(self, "Your video metadata has been updated")
         except:
             QMaemo5InformationBox.information(self, "Unable to update your video metadata") 
@@ -258,13 +267,13 @@ class EditPlaylistVideoDialog(NewPlaylistDialog):
     Dialog enabling the user to edit the custom 
     metadata of the playlist video.
     """
-    def __init__(self, parent, playlistId, playlistVideo, position, count):
+    def __init__(self, parent, playlist_uri, playlistVideo, position, count):
         """
         Constructor
         """
         NewPlaylistDialog.__init__(self, parent)
         self.setWindowTitle("Edit Custom Metadata")
-        self.playlistId = playlistId
+        self.playlist_uri = playlist_uri
         self.playlistVideo = playlistVideo
         self.privateCheckBox.setVisible(False) 
         self.titleEdit.setText(unicode(self.playlistVideo.title.text, "utf-8"))
@@ -312,16 +321,16 @@ class EditPlaylistVideoDialog(NewPlaylistDialog):
         newVideoTitle = unicode(self.titleEdit.text())
         newVideoDescription = unicode(self.descriptionEdit.toPlainText())
         newPosition = unicode(self.positionButton.valueText())
-        playlistVideoId = self.playlistVideo.media.video_id.text
+        playlistentryId = self.playlist_uri.replace("?v=2","").split("/")[-1:][0]
+        self.playlist_uri = self.playlist_uri.replace(playlistentryId,"")[:-5]
         try:
             self.toggleBusy(True)
-            youtubeservice.YouTubeDataService.updatePlaylistVideo(self.playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition)
+            youtubeservice.YouTubeDataService.updatePlaylistVideo(self.playlist_uri, playlistentryId, newVideoTitle, newVideoDescription, newPosition)
             QMaemo5InformationBox.information(self, "Your custom metadata has been updated")
         except:
             QMaemo5InformationBox.information(self, "Unable to update your custom metadata") 
         self.toggleBusy(False)
         self.accept()      
-        
 
 class ConfirmDeleteDialog(QDialog, Ui_ConfirmDeleteDialog):
     """
