@@ -1,8 +1,5 @@
 # -*- coding: utf-8 -*-
 
-"""
-Module implementing CutetubeWindows.
-"""
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
@@ -48,15 +45,15 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             self.actionDownloads.setText("Downloads (%d videos)" % taskQueueLength)
         self.connect(closeFilter, SIGNAL("triggered()"), self.closeFilter)
         self.connect(self.actionAddToQueue, SIGNAL("triggered()"), self.addToQueue)
+        self.connect(self.actionPlaying, SIGNAL("triggered()"), self.VideoPlaying)
         self.connect(self.actionAddToPlaylist, SIGNAL("triggered()"), self.addToPlaylist)
         self.connect(self.actionAddToFavourites, SIGNAL("triggered()"), self.addToFavourites)
         self.connect(self.actionDeleteVideo, SIGNAL("triggered()"), self.confirmVideoDelete)
-        self.connect(self.actionEditVideo, SIGNAL("triggered()"), self.editVideo)
         self.connect(self.moreButton, SIGNAL("pressed()"), self.changeButtonStyleSheet)
         self.connect(self.moreButton, SIGNAL("released()"), self.changeButtonStyleSheet)
         self.orientationChanged()
-        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged) 
-        
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+       
     def changeButtonStyleSheet(self):
         """
         Setting the QToolButton style sheets in the conventional 
@@ -109,7 +106,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             self.listWidget.setRowHidden(row, False)
         self.toolBar.setVisible(False)
 
-    def toggleBusy(self, isBusy):
+    def toggleBusy(self, isBusy = False):
         """
         Shows the progress indicator if argument is True, 
         and hides it otherwise.
@@ -132,6 +129,19 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             QMaemo5InformationBox.information(self, "Unable to add video to your playback queue")
         self.listWidget.setCurrentRow(-1)
 
+    def VideoPlaying(self, event = None):
+        """
+        Plays the video.
+        """
+        row = self.listWidget.currentRow()
+        video = self.yt.videoList[row]
+        try:
+            self.toggleBusy(True)
+            videoPlaybackWindow = VideoPlaybackWindow(self, video = video)
+        except:
+            QMaemo5InformationBox.information(self, "Unable to play video")
+        self.toggleBusy()
+
     def addToPlaylist(self):
         row = self.listWidget.currentRow()
         video = self.yt.videoList[row]
@@ -144,7 +154,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         videoId = video.media.video_id.text
         try:
             addedToFavourites = youtubeservice.YouTubeDataService.addVideoToFavourites(videoId)
-            if addedToFavourites == True:
+            if addedToFavourites:
                 QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(video.title.text, "utf-8"))
             else:
                 QMaemo5InformationBox.information(self, addedToFavourites)
@@ -160,21 +170,16 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         self.listWidget.setCurrentRow(-1)
 
     def deleteVideo(self):
+        for link in self.video.link:
+            if link.rel == "self":
+                video_uri = link.href
         try:
-            self.yt.deleteVideo(self.video.id.text)
+            youtubeservice.YouTubeDataService.deleteVideo(video_uri)
             self.reloadData()
-            QMaemo5InformationBox.information(self, "\'%s\' has been deleted from your channel" % unicode(video.media.title.text, "utf-8"))
         except:
             QMaemo5InformationBox.information(self, "Unable to delete video from your channel")
         self.listWidget.setCurrentRow(-1)
 
-    def editVideo(self):
-        row = self.listWidget.currentRow()
-        video = self.yt.videoList[row]
-        editVideoDialog = cutetubedialogs.EditVideoDialog(self, video)
-        self.listWidget.setCurrentRow(-1)
-        self.connect(editVideoDialog, SIGNAL("accepted()"), self.reloadData)
-
     def loadData(self):
         try:
             self.yt.start()
@@ -240,7 +245,8 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         item = self.listWidget.item(row)
         thumbLabel = self.listWidget.itemWidget(item).thumbLabel
         try:
-            thumbLabel.setPixmap(thumbnail) 
+            thumbLabel.setPixmap(thumbnail)
+            thumbLabel.mouseReleaseEvent = self.VideoPlaying
         except:
             thumbLabel.setPixmap(QPixmap(":/images/ui-images/thumbnail.png"))
 
@@ -420,7 +426,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             QMaemo5InformationBox.information(self, "Your chosen videos have been added to your favourites")
         except:
             QMaemo5InformationBox.information(self, "Unable to add videos to your favourites")
-        self.toggleBusy(False)
+        self.toggleBusy()
         self.actionPencil.toggle()
 
     def queueChanged(self, queueLength):
@@ -446,6 +452,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         else:
             self.actionDownloads.setVisible(False)
         self.emit(SIGNAL("downloadsChanged(int)"), taskQueueLength)
+ 
 
 class MostRecentWindow(CutetubeWindows):
     """
@@ -457,50 +464,122 @@ class MostRecentWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Most Recent")
+        self.actionPlaying.setVisible(True)
         self.actionAddToQueue.setVisible(True)
         if youtubeservice.YouTubeDataService.currentUser != "":
             self.actionAddToFavourites.setVisible(True)
             self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
+        self.tline = "?time=today"
+        self.feedType = "most_viewed"
+        self.showfeedMenus(True)            
         self.show()
-        location = YouTubeAPISettings.locationFilter
-        category = YouTubeAPISettings.categoryFilter
-        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/%smost_recent%s" % (location, category)
-        self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
-        self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)   
-        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
-        self.loadData()
-        
+        self.switchFT()
+        self.showtimePushbutton(True)
+        self.timePushButtonToggled(0)
 
-class MostViewedWindow(CutetubeWindows):
-    """
-    Displays videos from the 'Most Viewed' feed.
-    """
-    def __init__(self, parent):
-        """
-        Constructor
-        """
-        CutetubeWindows.__init__(self, parent)
-        self.setWindowTitle("Today's Most Viewed")
-        self.actionAddToQueue.setVisible(True)
-        if youtubeservice.YouTubeDataService.currentUser != "":
-            self.actionAddToFavourites.setVisible(True)
-            self.actionAddToPlaylist.setVisible(True)
-        self.actionPencil.setVisible(True)
-        self.pencilList = []
-        self.show()
+    def showfeedMenus(self, a = False):        
+        for b in (self.switchFeed, self.switchFeed1, self.switchFeed2, self.switchFeed3, self.switchFeed4, self.switchFeed5, self.switchFeed6):
+            b.setVisible(a)        
+
+    def showtimePushbutton(self, a = False):        
+        for b in (self.timePushButton, self.timePushButton1, self.timePushButton2, self.timePushButton3):
+            b.setVisible(a)
+
+    def timePushButtonToggled(self, a):
+        i = 0
+        for button in (self.timePushButton, self.timePushButton1, self.timePushButton2, self.timePushButton3):
+            if i == a:
+                button.setStyleSheet("color: black; margin: 8px 0 0 0; border-radius: 3px; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #10FF31, stop: 1 #E7FFB5);")
+            else:
+                button.setStyleSheet("margin: 8px 0 0 0; border-radius: 3px; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #39B6FF, stop: 1 #0075BD);")
+            i += 1
+            
+    @pyqtSignature("")
+    def on_timePushButton_clicked(self):
+        self.tline = "?time=today"
+        self.switchFT()
+        self.timePushButtonToggled(0)
+
+    @pyqtSignature("")   
+    def on_timePushButton1_clicked(self):
+        self.tline = "?time=this_week"
+        self.switchFT()
+        self.timePushButtonToggled(1)
+
+    @pyqtSignature("")   
+    def on_timePushButton2_clicked(self):
+        self.tline = "?time=this_month"
+        self.switchFT()
+        self.timePushButtonToggled(2)
+
+    @pyqtSignature("")   
+    def on_timePushButton3_clicked(self):
+        self.tline = "?time=all_time"
+        self.switchFT()
+        self.timePushButtonToggled(3)
+
+    @pyqtSignature("")
+    def on_switchFeed_triggered(self):
+        self.feedType = "top_rated"
+        self.switchFT()
+        self.showtimePushbutton(True)
+
+    @pyqtSignature("")
+    def on_switchFeed1_triggered(self):
+        self.showtimePushbutton()
+        self.tlinerecord = self.tline
+        self.tline = ""
+        self.feedType = "recently_featured"
+        self.switchFT()
+        self.tline = self.tlinerecord
+
+    @pyqtSignature("")
+    def on_switchFeed2_triggered(self):
+        self.feedType = "most_discussed"
+        self.switchFT()
+        self.showtimePushbutton(True)
+
+    @pyqtSignature("")
+    def on_switchFeed3_triggered(self):
+        self.feedType = "top_favorites"
+        self.switchFT()
+        self.showtimePushbutton(True)
+        
+    @pyqtSignature("")
+    def on_switchFeed4_triggered(self):
+        self.feedType = "most_responded"
+        self.switchFT()
+        self.showtimePushbutton(True)
+
+    @pyqtSignature("")
+    def on_switchFeed5_triggered(self):
+        self.feedType = "most_recent"
+        self.showtimePushbutton()
+        self.tlinerecord = self.tline
+        self.tline = ""
+        self.switchFT()
+        self.tline = self.tlinerecord
+        
+    @pyqtSignature("")
+    def on_switchFeed6_triggered(self):
+        self.feedType = "most_viewed"
+        self.switchFT()
+        self.showtimePushbutton(True)
+
+    def switchFT(self):
+        feedTypes = { "most_viewed": "Most Viewed", "top_rated": "Top Rated", "recently_featured": "Recently Featured", "most_discussed": "Most Discussed", "top_favorites": "Top Favorites", "most_responded": "Most Responded", "most_recent": "Most Recent" }
+        self.setWindowTitle(feedTypes[self.feedType])
         location = YouTubeAPISettings.locationFilter
         category = YouTubeAPISettings.categoryFilter
-        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/%smost_viewed%s?time=today" % (location, category)
+        self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/%s%s%s%s" % (location, self.feedType, category, self.tline)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
-        self.loadData()
+        self.reloadData()
         
 class SearchResultsWindow(CutetubeWindows):
     """
@@ -513,6 +592,7 @@ class SearchResultsWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Search Results")
+        self.actionPlaying.setVisible(True)
         self.actionAddToQueue.setVisible(True)
         if youtubeservice.YouTubeDataService.currentUser != "":
             self.actionAddToFavourites.setVisible(True)
@@ -575,13 +655,12 @@ class UploadsWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("My Uploads")
-        #self.actionNewUpload.setVisible(True)
         self.actionSearch.setVisible(True)
         self.actionSearch.setText("Search my uploads")
+        self.actionPlaying.setVisible(True)
         self.actionAddToQueue.setVisible(True)
         self.actionAddToFavourites.setVisible(True)
         self.actionAddToPlaylist.setVisible(True)
-        self.actionEditVideo.setVisible(True)
         self.actionDeleteVideo.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
@@ -618,6 +697,7 @@ class UserWindow(CutetubeWindows):
             self.actionSubscribe.setText("Subscribe to \'%s\'" % unicode(self.username, "utf-8"))
         self.actionSearch.setVisible(True)
         self.actionSearch.setText("Search user's videos")
+        self.actionPlaying.setVisible(True)
         self.actionAddToQueue.setVisible(True)
         if youtubeservice.YouTubeDataService.currentUser != "":
             self.actionAddToFavourites.setVisible(True)
@@ -650,6 +730,7 @@ class RelatedVideosWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Related Videos")
+        self.actionPlaying.setVisible(True)
         self.actionAddToQueue.setVisible(True)
         if youtubeservice.YouTubeDataService.currentUser != "":
             self.actionAddToFavourites.setVisible(True)
@@ -678,6 +759,7 @@ class FavouritesWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("My Favourites")
+        self.actionPlaying.setVisible(True)
         self.actionAddToQueue.setVisible(True)
         self.actionAddToPlaylist.setVisible(True)
         self.actionRemoveFromFavourites.setVisible(True)
@@ -754,7 +836,7 @@ class PlaylistsWindow(CutetubeWindows):
             item = QListWidgetItem(playlist.title.text)
             item.setTextAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
             self.listWidget.addItem(item)
-        self.toggleBusy(False)
+        self.toggleBusy()
 
     def editPlaylist(self):
         row = self.listWidget.currentRow()
@@ -833,11 +915,11 @@ class PlaylistVideosWindow(CutetubeWindows):
         self.actionPlayPlaylist.setVisible(True)
         self.actionSearch.setVisible(True)
         self.actionSearch.setText("Find more of \'%s\'" % self.playlistName)
+        self.actionPlaying.setVisible(True)
         self.actionAddToQueue.setVisible(True)
         self.actionAddToFavourites.setVisible(True)
         self.actionAddToPlaylist.setVisible(True)
         self.actionRemoveFromPlaylist.setVisible(True)
-        self.actionEditVideo.setVisible(True)
         self.actionPencil.setVisible(True)
         self.connect(self.actionRemoveFromPlaylist, SIGNAL("triggered()"), self.removeFromPlaylist)
         self.pencilList = []
@@ -850,15 +932,6 @@ class PlaylistVideosWindow(CutetubeWindows):
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
 
-    def editVideo(self):
-        row = self.listWidget.currentRow()
-        playlistVideo = self.yt.videoList[row]
-        position = row + 1
-        count = len(self.yt.videoList)
-        editPlaylistVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, self.playlistId, playlistVideo, position, count)
-        self.listWidget.setCurrentRow(-1)
-        self.connect(editPlaylistVideoDialog, SIGNAL("accepted()"), self.reloadData)
-
     def addToPlaylist(self):
         row = self.listWidget.currentRow()
         video = self.yt.videoList[row]
@@ -1098,8 +1171,11 @@ class SubscriptionsWindow(CutetubeWindows):
     def removeSubscription(self):
         row = self.listWidget.currentRow()
         subscription = self.yt.subscriptionsFeed.entry[row]
+        for link in subscription.link:
+            if link.rel == "self":
+                subscription_uri = link.href
         try:
-            unsubscribed = youtubeservice.YouTubeDataService.removeSubscription(subscription.id.text)
+            unsubscribed = youtubeservice.YouTubeDataService.removeSubscription(subscription_uri)
             if unsubscribed == True:
                 self.listWidget.setRowHidden(row, True)
                 QMaemo5InformationBox.information(self, "You have unsubscribed to \'%s\'" % unicode(subscription.username.text, "utf-8"))
@@ -1133,7 +1209,7 @@ class SubscriptionsWindow(CutetubeWindows):
             item = QListWidgetItem(subscription.username.text)
             item.setTextAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
             self.listWidget.addItem(item)
-        self.toggleBusy(False)
+        self.toggleBusy()
 
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
@@ -1486,7 +1562,7 @@ class CommentsWindow(CutetubeWindows):
                     self.listWidget.setItemWidget(item, commentWidget)
             except AttributeError:
                 pass
-        self.toggleBusy(False)
+        self.toggleBusy()
 
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
