@@ -27,14 +27,10 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         self.setupUi(self)
         self.setAttribute(Qt.WA_Maemo5StackedWindow) 
         self.setWindowTitle("My Channel")
-        self.youtubeLabel = QLabel(self)
-        self.youtubeLabel.setGeometry(QRect(10, 10, 294, 87))
-        self.youtubeLabel.setPixmap(QPixmap(":/images/ui-images/banner.png"))
-        self.youtubeLabel.setScaledContents(True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged) 
         self.orientationChanged()
         for button in (self.uploadsButton, self.favouritesButton, self.playlistsButton, self.subscriptionsButton):
-            button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;")
+            button.setStyleSheet("border-radius: 10px; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #39B6FF, stop: 1 #0075BD);")
             self.connect(button,  SIGNAL("pressed()"), self.changeButtonStyleSheet)
             self.connect(button,  SIGNAL("released()"), self.changeButtonStyleSheet)
         self.keyPressEvent = self.showSearchDialog
@@ -59,9 +55,9 @@ class MyAccountWindow(QMainWindow, Ui_MyAccountWindow):
         """
         button = self.sender()
         if button.isDown():
-            button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px; background-color: rgb(120, 120, 120)")
+            button.setStyleSheet("border-radius: 10px; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0075BD, stop: 1 #39B6FF);")
         else:
-            button.setStyleSheet("border: 2px solid rgb(120, 120, 120); border-radius: 6px;") 
+            button.setStyleSheet("border-radius: 10px; background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #39B6FF, stop: 1 #0075BD);") 
         
     def showSearchDialog(self,  event):
         """
