@@ -111,10 +111,13 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         # Load the title and description. Some videos do not have a description, in which case None is returned.
         self.actionUserVideos.setText("%s\'s Videos" % unicode(self.video.media.credit.text, "utf-8"))
-        self.titleLabel.setText(unicode(self.video.title.text, "utf-8"))       
+        self.titleLabel.setText(unicode(self.video.title.text, "utf-8"))
+        for link in self.video.link:
+            if link.rel == "self":
+                video_uri = link.href
         try:
-            if "playlist" in self.video.id.text:
-                self.descriptionTextBox.setText(unicode(self.video.content.text, "utf-8"))
+            if ("playlist" in video_uri and self.video.summary):
+                self.descriptionTextBox.setText(unicode(self.video.summary.text, "utf-8"))
             else:
                 self.descriptionTextBox.setText(unicode(self.video.media.description.text, "utf-8"))
         except:
@@ -152,7 +155,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         # Load video duration, converting seconds to MM:SS format.
         self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(self.video.media.duration.seconds)))))
         
-        thumbUrl = self.video.media.thumbnail[4].url
+        thumbUrl = self.video.media.thumbnail[1].url
         thumbnail = youtubeservice.YouTubeDataService.getVideoThumbnail(thumbUrl)
         try:
             self.thumbLabel.setPixmap(thumbnail) 
@@ -325,12 +328,16 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         Raises an EditVideoDialog.
         """
-        if "playlist" in self.video.id.text:
-            editVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, self.playlistId, self.video, self.playlistPosition, self.playlistLength)
+        for link in self.video.link:
+            if link.rel == "self":
+                video_uri = link.href
+                
+        if "playlist" in video_uri:
+            editVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, video_uri, self.video, self.playlistPosition, self.playlistLength)
         else:
             editVideoDialog = cutetubedialogs.EditVideoDialog(self, self.video)
         self.connect(editVideoDialog, SIGNAL("accepted()"), self.loadData)
-
+        
     @pyqtSignature("")
     def on_ratingButton_clicked(self):
         """
