@@ -9,8 +9,6 @@ from PyQt4.phonon import Phonon
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from youtubeservice import YouTubeDataService, YouTubeVideoDownloader
 from cutetubeconfig import VideoPlaybackSettings, VideoDownloadSettings
-import resources_rc
-
 
 class VideoPlaybackWindow(Phonon.VideoPlayer):
     """
@@ -23,29 +21,33 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.video = video
         self.playlist = playlist
-        self.toolBar = QToolBar(self)
+        self.toolBar = QToolBar(self)        
         self.toolBar.setVisible(False)
+        self.muteButton = QAction(self.toolBar)
+        self.muteButton.setIcon(QIcon("/opt/cutetube/ui-images/vol.png"))
         self.playPauseButton = QAction(self.toolBar)
-        self.playPauseButton.setIcon(QIcon(":/images/ui-images/pauseicon.png"))
+        self.playPauseButton.setIcon(QIcon("/opt/cutetube/ui-images/pause.png"))
         self.stopButton = QAction(self.toolBar)
-        self.stopButton.setIcon(QIcon(":/images/ui-images/stopicon.png"))
+        self.stopButton.setIcon(QIcon("/opt/cutetube/ui-images/stop.png"))
         self.previousButton = QAction(self.toolBar)
-        self.previousButton.setIcon(QIcon(":/images/ui-images/previousicon.png"))
+        self.previousButton.setIcon(QIcon("/opt/cutetube/ui-images/rew.png"))
         self.nextButton = QAction(self.toolBar)
-        self.nextButton.setIcon(QIcon(":/images/ui-images/nexticon.png"))
+        self.nextButton.setIcon(QIcon("/opt/cutetube/ui-images/ff.png"))
         self.seekBar = Phonon.SeekSlider(self.mediaObject(), self.toolBar)
         self.toolBar.addAction(self.previousButton)
         self.toolBar.addAction(self.playPauseButton)
         self.toolBar.addAction(self.stopButton)
         self.toolBar.addAction(self.nextButton)
         self.toolBar.addWidget(self.seekBar)
+        self.toolBar.addAction(self.muteButton)
         self.titleLabel = QLabel(self)
         self.titleLabel.setVisible(False)
-        self.titleLabel.setFixedHeight(30)
+        self.titleLabel.setFixedHeight(30)        
         self.layout().addWidget(self.titleLabel)
         self.layout().addWidget(self.toolBar)
         self.mousePressEvent = self.toggleControls
         self.keyPressEvent = self.keyControl
+        self.connect(self.muteButton, SIGNAL("triggered()"), self.toggleMute)
         self.connect(self.stopButton, SIGNAL("triggered()"), self.stopAndClose)
         self.connect(self.playPauseButton, SIGNAL("triggered()"), self.playPause)
         self.connect(self.previousButton, SIGNAL("triggered()"), self.playPrevious)
@@ -89,7 +91,7 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
             videoTitle = unicode(self.video.media.title.text, "utf-8")
         except:
             videoTitle = unicode(self.playlist[self.currentVideo].media.title.text, "utf-8")
-        self.titleLabel.setText(" %s" % videoTitle)
+        self.titleLabel.setText("           %s" % videoTitle)
         QMaemo5InformationBox.information(self, "Playing \'%s\'" % videoTitle)        
         
     def toggleControls(self, event = None):
@@ -99,6 +101,15 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
         """
         self.titleLabel.setVisible(not self.titleLabel.isVisible())
         self.toolBar.setVisible(not self.toolBar.isVisible())
+
+    def toggleMute(self):
+        
+        if self.volume() > 0.0:
+            self.setVolume(0.0)
+            self.muteButton.setIcon(QIcon("/opt/cutetube/ui-images/volmuted.png"))
+        else:
+            self.setVolume(1.0)
+            self.muteButton.setIcon(QIcon("/opt/cutetube/ui-images/vol.png"))
         
     def keyControl(self, event):
         """
@@ -153,10 +164,10 @@ class VideoPlaybackWindow(Phonon.VideoPlayer):
         """
         if self.isPlaying():
             self.pause()
-            self.playPauseButton.setIcon(QIcon(":/images/ui-images/playicon.png"))
+            self.playPauseButton.setIcon(QIcon("/opt/cutetube/ui-images/play.png"))
         else:
             self.play()
-            self.playPauseButton.setIcon(QIcon(":/images/ui-images/pauseicon.png"))
+            self.playPauseButton.setIcon(QIcon("/opt/cutetube/ui-images/pause.png"))
             
     def playPrevious(self):
         """
