@@ -27,8 +27,8 @@ class YouTubeDataService(object):
     ytService = gdata.youtube.service.YouTubeService()
     ytService.email = ""
     ytService.password = ""
-    ytService.source = "cuteTube"
-    ytService.developer_key = "AI39si6x9O1gQ1Z_BJqo9j2n_SdVsHu1pk2uqvoI3tVq8d6alyc1og785IPCkbVY3Q5MFuyt-IFYerMYun0MnLdQX5mo2BueSw"
+    ytService.source = "Ytube"
+    ytService.developer_key = "AI39si6YT7uxB9Zwrj1xW86FNKrUC92lYrPhoh6BwkcBzb_7E9Kiq9-HlqWC_DKvcaE6hq9r_wHjoMoUQAG70fTCUYmcKb4RcQ"
     stdHeaders = {
     'User-Agent': 'Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.8) Gecko/20100723 Firefox/3.6.8',
     'Accept-Charset': 'ISO-8859-1,utf-8;q=0.7,*;q=0.7',
@@ -140,14 +140,10 @@ class YouTubeDataService(object):
         """
         Creates a new playlist using the title and description arguments.
         """
-        try:
-            YouTubeDataService.ytService.AddPlaylist(playlistTitle, playlistDescription, private)
-            result = True
-        except gdata.service.Error, e:
-            result = e.args[0].get("body")
-            CutetubeLog.logException(e)
-        return result
-
+        new_playlistentry = YouTubeDataService.ytService.AddPlaylist(playlistTitle, playlistDescription, private)
+        if isinstance(new_playlistentry, gdata.youtube.YouTubePlaylistEntry):
+            return True
+        return False
 
     @staticmethod
     def addVideoToPlaylist(playlistId, videoId):
@@ -172,8 +168,8 @@ class YouTubeDataService(object):
         return result
 
     @staticmethod
-    def updatePlaylistVideo(playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition):
-        YouTubeDataService.ytService.UpdatePlaylistVideoEntryMetaData(playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition)
+    def updatePlaylistVideo(playlist_uri, playlistentryId, newVideoTitle, newVideoDescription, newPosition):
+        YouTubeDataService.ytService.UpdatePlaylistVideoEntryMetaData(playlist_uri, playlistentryId, newVideoTitle, newVideoDescription, newPosition)
 
     @staticmethod
     def updatePlaylist(playlistId, newPlaylistTitle, newPlaylistDescription, private):
@@ -191,7 +187,7 @@ class YouTubeDataService(object):
         return result
 
     @staticmethod
-    def getVideoEntry(videoId, apiVersion = 1):
+    def getVideoEntry(videoId, apiVersion=1):
         try:
             videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_id = videoId, api_version = apiVersion)
         except:
@@ -228,19 +224,18 @@ class YouTubeDataService(object):
         return thumbnail
 
     @staticmethod
-    def updateVideo(videoId, newVideoTitle, newVideoDescription):
-        video = YouTubeDataService.getVideoEntry(videoId)
+    def updateVideo(video_uri, newVideoTitle, newVideoDescription):
+        video = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_uri)
         video.media.title.text = newVideoTitle
         video.media.description.text = newVideoDescription
-        video.link.append(atom.Link(rel='edit', href='http://gdata.youtube.com/feeds/api/users/%s/uploads/%s' % (YouTubeDataService.currentUser, videoId.split("/")[-1])))
         YouTubeDataService.ytService.UpdateVideoEntry(video)
 
     @staticmethod
-    def deleteVideo(videoId):
+    def deleteVideo(video_uri):
         """
         Deletes the video from the user's uploads.
         """
-        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(videoId)
+        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_uri)
         YouTubeDataService.ytService.DeleteVideoEntry(videoEntry)
 
     @staticmethod
@@ -647,9 +642,9 @@ class DownloadTask(QThread):
         # Create the target filename
         if VideoDownloadSettings.downloadFormat in (34, 35, 22):
             formatExt = "HQ"
-            self.filename = "%s/%s-%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"), formatExt)
+            self.filename = "%s/%s-%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[\"?#~!@=:/|\\\\]', "-", self.video.media.title.text), "utf-8"), formatExt)
         else:
-            self.filename = "%s/%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
+            self.filename = "%s/%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[\"?#~!@=:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
         self.tempname = self.filename + '.partial'
 
         self.totalSize = 0
